package cn.efunbox.audio.controller;

import cn.efunbox.audio.entity.Audio;
import cn.efunbox.audio.entity.Device;
import cn.efunbox.audio.entity.Record;
import cn.efunbox.audio.service.AudioService;
import cn.efunbox.audio.service.DeviceService;
import cn.efunbox.audio.service.RecordService;
import cn.efunbox.audio.util.ApiCode;
import cn.efunbox.audio.util.HttpUtil;
import com.netflix.ribbon.proxy.annotation.Http;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;

/**
 * Created by yao on 17-9-26.
 */
@RestController
@Slf4j
@RequestMapping(value = "/audio")
public class AudioController {

    @Autowired
    AudioService audioService;
    @Autowired
    DeviceService deviceService;
    @Autowired
    RecordService recordService;

    @RequestMapping(value = "/search" ,method = RequestMethod.POST)
    public void Search(HttpServletRequest request, HttpServletResponse response){
        String id = request.getParameter("id");
        String name = request.getParameter("name");
        String album = request.getParameter("album");
        if(name==null && album==null){
            HttpUtil.responseApiCode(request, response, ApiCode.PARAMETER_ERROR);
            return;
        }
        List<Audio> list = null;
        if(name!=null && name.length()>0  && album!=null && album.length()>0)
            list = audioService.SearchByNameAlbum(name, album);
        else if(name!=null && name.length()>0)
            list = audioService.SearchByName(name);
        else
            list = audioService.SearchByAlbum(album);

        if(list==null || list.size()<1){
            HttpUtil.responseApiCode(request, response, ApiCode.NOT_FOUND);
            return;
        }
        Device device = deviceService.GetOne(Long.valueOf(id));
        if(device==null){
            HttpUtil.responseApiCode(request, response, ApiCode.PARAMETER_ERROR);
            return;
        }
        Random random = new Random();
        int r = Math.abs(random.nextInt())%list.size();
        Audio audio = list.get(r);

        Record record = new Record();
        record.setIdDevice(device.getId());
        record.setIdChannel(device.getIdChannel());
        record.setIdAudio(audio.getId());
        record.setCreated(new Date());
        recordService.Insert(record);

        HttpUtil.responseOkData(request, response, audio);
        return;
    }

    @RequestMapping(value = "/insert", method = RequestMethod.POST)
    public void Insert(HttpServletRequest request, HttpServletResponse response){
        String album = request.getParameter("album");
        String lesson = request.getParameter("lesson");
        String name = request.getParameter("name");
        String url = request.getParameter("url");
        if(album==null || name==null && url==null){
            HttpUtil.responseApiCode(request, response, ApiCode.PARAMETER_ERROR);
            return;
        }

        Audio audio = new Audio();
        audio.setAlbum(album);
        if(lesson!=null && lesson.length()>0)
            audio.setLesson(Integer.valueOf(lesson));
        audio.setName(name);
        audio.setUrl(url);
        audio.setCreated(new Date());
        audio = audioService.Insert(audio);

        HttpUtil.responseOutWithJson(request, response, audio);
        return;
    }

}
